@@ -7,38 +7,6 @@ a = 6378245.0  # 长半轴
 ee = 0.00669342162296594323  # 偏心率平方
 
 
-def gcj02_to_bd09(lat, lng):
-    """
-    火星坐标系(GCJ-02)转百度坐标系(BD-09)
-    谷歌、高德——>百度
-    :param lng:火星坐标经度
-    :param lat:火星坐标纬度
-    :return:
-    """
-    z = math.sqrt(lng * lng + lat * lat) + 0.00002 * math.sin(lat * x_pi)
-    theta = math.atan2(lat, lng) + 0.000003 * math.cos(lng * x_pi)
-    bd_lng = z * math.cos(theta) + 0.0065
-    bd_lat = z * math.sin(theta) + 0.006
-    return [bd_lat, bd_lng]
-
-
-def bd09_to_gcj02(bd_lat, bd_lon):
-    """
-    百度坐标系(BD-09)转火星坐标系(GCJ-02)
-    百度——>谷歌、高德
-    :param bd_lat:百度坐标纬度
-    :param bd_lon:百度坐标经度
-    :return:转换后的坐标列表形式
-    """
-    x = bd_lon - 0.0065
-    y = bd_lat - 0.006
-    z = math.sqrt(x * x + y * y) - 0.00002 * math.sin(y * x_pi)
-    theta = math.atan2(y, x) - 0.000003 * math.cos(x * x_pi)
-    gg_lng = z * math.cos(theta)
-    gg_lat = z * math.sin(theta)
-    return [gg_lat, gg_lng]
-
-
 def wgs84_to_gcj02(lat, lng):
     """
     WGS84转GCJ02(火星坐标系)
@@ -79,17 +47,7 @@ def gcj02_to_wgs84(lat, lng):
     return [lat * 2 - mglat, lng * 2 - mglng]
 
 
-def bd09_to_wgs84(bd_lat, bd_lon):
-    lat, lon = bd09_to_gcj02(bd_lon, bd_lat)
-    return gcj02_to_wgs84(lon, lat)
-
-
-def wgs84_to_bd09(lon, lat):
-    lat, lon = wgs84_to_gcj02(lon, lat)
-    return gcj02_to_bd09(lon, lat)
-
-
-def _transformlat(lat, lng):
+def _transformlat(lng, lat):
     ret = -100.0 + 2.0 * lng + 3.0 * lat + 0.2 * lat * lat + \
           0.1 * lng * lat + 0.2 * math.sqrt(math.fabs(lng))
     ret += (20.0 * math.sin(6.0 * lng * pi) + 20.0 *
@@ -101,7 +59,7 @@ def _transformlat(lat, lng):
     return ret
 
 
-def _transformlng(lat, lng):
+def _transformlng(lng, lat):
     ret = 300.0 + lng + 2.0 * lat + 0.1 * lng * lng + \
           0.1 * lng * lat + 0.1 * math.sqrt(math.fabs(lng))
     ret += (20.0 * math.sin(6.0 * lng * pi) + 20.0 *
@@ -114,13 +72,10 @@ def _transformlng(lat, lng):
 
 
 if __name__ == '__main__':
-    lat_1 = 22.519539
-    lng_1 = 113.929511
-    result1 = gcj02_to_bd09(lat_1, lng_1)
-    result2 = bd09_to_gcj02(lat_1, lng_1)
-    result3 = wgs84_to_gcj02(lat_1, lng_1)
-    result4 = gcj02_to_wgs84(lat_1, lng_1)
-    result5 = bd09_to_wgs84(lat_1, lng_1)
-    result6 = wgs84_to_bd09(lat_1, lng_1)
+    lng_1 = 22.543170688239
+    lat_1 = 113.91904493026368
 
-    print(result1, result2, result3, result4, result5, result6)
+    result3 = wgs84_to_gcj02(lng_1, lat_1)
+    result4 = gcj02_to_wgs84(lng_1, lat_1)
+
+    print(result3, result4)
